@@ -8,6 +8,7 @@ class RemoteServer:
         'id': None,     # int64 - Remote server ID
         'authentication_method': None,     # string - Type of authentication method
         'hostname': None,     # string - Hostname or IP address
+        'remote_home_path': None,     # string - Initial home folder on remote server
         'name': None,     # string - Internal name for your reference
         'port': None,     # int64 - Port for remote server.  Not needed for S3.
         'max_connections': None,     # int64 - Max number of parallel connections.  Ignored for S3 connections (we will parallelize these as much as possible).
@@ -31,6 +32,7 @@ class RemoteServer:
         'auth_status': None,     # string - Either `in_setup` or `complete`
         'auth_account_name': None,     # string - Describes the authorized account
         'one_drive_account_type': None,     # string - Either personal or business_other account types
+        'sharepoint_hostname': None,     # string - Cloud hosted sharepoint hostname
         'azure_blob_storage_account': None,     # string - Azure Blob Storage Account name
         'azure_blob_storage_container': None,     # string - Azure Blob Storage Container name
         'aws_access_key': None,     # string - AWS Access Key.
@@ -98,6 +100,7 @@ class RemoteServer:
     #   rackspace_region - string - Three letter airport code for Rackspace region. See https://support.rackspace.com/how-to/about-regions/
     #   rackspace_container - string - The name of the container (top level directory) where files will sync.
     #   one_drive_account_type - string - Either personal or business_other account types
+    #   sharepoint_hostname - string - Cloud hosted sharepoint hostname
     #   azure_blob_storage_account - string - Azure Blob Storage Account name
     #   azure_blob_storage_container - string - Azure Blob Storage Container name
     def update(self, params = None):
@@ -178,6 +181,8 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: rackspace_container must be an str")
         if "one_drive_account_type" in params and not isinstance(params["one_drive_account_type"], str):
             raise InvalidParameterError("Bad parameter: one_drive_account_type must be an str")
+        if "sharepoint_hostname" in params and not isinstance(params["sharepoint_hostname"], str):
+            raise InvalidParameterError("Bad parameter: sharepoint_hostname must be an str")
         if "azure_blob_storage_account" in params and not isinstance(params["azure_blob_storage_account"], str):
             raise InvalidParameterError("Bad parameter: azure_blob_storage_account must be an str")
         if "azure_blob_storage_container" in params and not isinstance(params["azure_blob_storage_container"], str):
@@ -214,6 +219,10 @@ class RemoteServer:
 #   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 def list(params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
     if "per_page" in params and not isinstance(params["per_page"], int):
@@ -276,9 +285,14 @@ def get(id, params = None, options = None):
 #   rackspace_region - string - Three letter airport code for Rackspace region. See https://support.rackspace.com/how-to/about-regions/
 #   rackspace_container - string - The name of the container (top level directory) where files will sync.
 #   one_drive_account_type - string - Either personal or business_other account types
+#   sharepoint_hostname - string - Cloud hosted sharepoint hostname
 #   azure_blob_storage_account - string - Azure Blob Storage Account name
 #   azure_blob_storage_container - string - Azure Blob Storage Container name
 def create(params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
     if "aws_access_key" in params and not isinstance(params["aws_access_key"], str):
         raise InvalidParameterError("Bad parameter: aws_access_key must be an str")
     if "aws_secret_key" in params and not isinstance(params["aws_secret_key"], str):
@@ -345,6 +359,8 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: rackspace_container must be an str")
     if "one_drive_account_type" in params and not isinstance(params["one_drive_account_type"], str):
         raise InvalidParameterError("Bad parameter: one_drive_account_type must be an str")
+    if "sharepoint_hostname" in params and not isinstance(params["sharepoint_hostname"], str):
+        raise InvalidParameterError("Bad parameter: sharepoint_hostname must be an str")
     if "azure_blob_storage_account" in params and not isinstance(params["azure_blob_storage_account"], str):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_account must be an str")
     if "azure_blob_storage_container" in params and not isinstance(params["azure_blob_storage_container"], str):
@@ -387,6 +403,7 @@ def create(params = None, options = None):
 #   rackspace_region - string - Three letter airport code for Rackspace region. See https://support.rackspace.com/how-to/about-regions/
 #   rackspace_container - string - The name of the container (top level directory) where files will sync.
 #   one_drive_account_type - string - Either personal or business_other account types
+#   sharepoint_hostname - string - Cloud hosted sharepoint hostname
 #   azure_blob_storage_account - string - Azure Blob Storage Account name
 #   azure_blob_storage_container - string - Azure Blob Storage Container name
 def update(id, params = None, options = None):
@@ -463,6 +480,8 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: rackspace_container must be an str")
     if "one_drive_account_type" in params and not isinstance(params["one_drive_account_type"], str):
         raise InvalidParameterError("Bad parameter: one_drive_account_type must be an str")
+    if "sharepoint_hostname" in params and not isinstance(params["sharepoint_hostname"], str):
+        raise InvalidParameterError("Bad parameter: sharepoint_hostname must be an str")
     if "azure_blob_storage_account" in params and not isinstance(params["azure_blob_storage_account"], str):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_account must be an str")
     if "azure_blob_storage_container" in params and not isinstance(params["azure_blob_storage_container"], str):
